﻿using System;

using Prism.Commands;
using Prism.Mvvm;

using TestLibrary;

namespace TestModule.ViewModels
{
    /// <summary>
    /// 탭 뷰 모델
    /// </summary>
    public class TabViewModel : BindableBase
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 애플리케이션 명령
        /// </summary>
        private IApplicationCommand applicationCommand;

        /// <summary>
        /// 제목
        /// </summary>
        private string title;

        /// <summary>
        /// 업데이트 가능 여부
        /// </summary>
        private bool canUpdate = true;

        /// <summary>
        /// 업데이트 텍스트
        /// </summary>
        private string updatedText;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 제목 - Title

        /// <summary>
        /// 제목
        /// </summary>
        public string Title
        {
            get
            {
                return this.title;
            }
            set
            {
                SetProperty(ref this.title, value);
            }
        }

        #endregion
        #region 업데이트 가능 여부 - CanUpdate

        /// <summary>
        /// 업데이트 가능 여부
        /// </summary>
        public bool CanUpdate
        {
            get
            {
                return this.canUpdate;
            }
            set
            {
                SetProperty(ref this.canUpdate, value);
            }
        }

        #endregion
        #region 업데이트 텍스트 - UpdateText

        /// <summary>
        /// 업데이트 텍스트
        /// </summary>
        public string UpdateText
        {
            get
            {
                return this.updatedText;
            }
            set
            {
                SetProperty(ref this.updatedText, value);
            }
        }

        #endregion
        #region 업데이트 명령 - UpdateCommand

        /// <summary>
        /// 업데이트 명령
        /// </summary>
        public DelegateCommand UpdateCommand { get; private set; }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - TabViewModel(applicationCommand)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="applicationCommand">애플리케이션 명령</param>
        public TabViewModel(IApplicationCommand applicationCommand)
        {
            this.applicationCommand = applicationCommand;

            UpdateCommand = new DelegateCommand(Update).ObservesCanExecute(() => CanUpdate);

            this.applicationCommand.SaveCommand.RegisterCommand(UpdateCommand);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 업데이트하기 - Update()

        /// <summary>
        /// 업데이트하기
        /// </summary>
        private void Update()
        {
            UpdateText = $"Updated : {DateTime.Now}";
        }

        #endregion
    }
}